pub enum LogsCap {
Push,
SetLevel,
Fetch,
}Expand description
Capabilities for the log collection feature.
Variants
Push
Permits the bearer to push log lines to the cloud.
SetLevel
Permits the bearer to set the log level filter on the issuer at runtime.
Fetch
Permits the bearer to ask the issuer for the contents of its local rolling log file.