pub struct Caps(/* private fields */);Expand description
Capabilities accepted by iroh-services.
Construct a capability set with one of the provided methods. The underlying wire representation is private to this crate.
Implementations