pub fn preset() -> PresetBuilderExpand description
Start a new IrohServicesPreset builder seeded with iroh-services
defaults: the n0 production relay map and no explicit secret key (the
endpoint will generate one at bind time).
pub fn preset() -> PresetBuilderStart a new IrohServicesPreset builder seeded with iroh-services
defaults: the n0 production relay map and no explicit secret key (the
endpoint will generate one at bind time).