pub struct PutLogs {
pub session_id: Uuid,
pub lines: Vec<LogLine>,
pub dropped: u32,
}Expand description
A batch of log lines pushed from a client to the cloud.
Fields
session_id: Uuidlines: Vec<LogLine>dropped: u32Number of lines dropped on the client since the last successful push, either due to the buffer being full or the throttle being exceeded.