ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder { /* private fields */ }
ClientBuilder provides configures and builds a iroh-services client, typically created with Client::builder

Implementations

Source

impl ClientBuilder

pub fn new(endpoint: &Endpoint) -> Self

pub fn register_metrics_group( self, metrics_group: Arc<dyn MetricsGroup>, ) -> Self

Register a metrics group to forward to iroh-services

The default registered metrics uses only the endpoint

pub fn metrics_interval(self, interval: Duration) -> Self

Set the metrics collection interval

Defaults to enabled, every 60 seconds.

pub fn disable_metrics_interval(self) -> Self

Disable metrics collection.

pub fn api_secret_from_env(self) -> Result<Self>

Check IROH_SERVICES_API_SECRET environment variable for a valid API secret

pub fn api_secret_from_str(self, secret_key: &str) -> Result<Self>

set client API secret from an encoded string

pub fn api_secret(self, ticket: ApiSecret) -> Result<Self>

Use a shared secret & remote iroh-services endpoint ID contained within a ticket to construct a iroh-services client. The resulting client will have “Client” capabilities.

API secrets include remote details within them, and will set both the remote and rcan values on the builder

pub async fn ssh_key_from_file<P: AsRef<Path>>(self, path: P) -> Result<Self>

Loads the private ssh key from the given path, and creates the needed capability.

pub fn ssh_key(self, key: &PrivateKey) -> Result<Self>

Creates the capability from the provided private ssh key.

pub fn rcan(self, cap: Rcan<Caps>) -> Result<Self>

Sets the rcan directly.

pub fn remote(self, remote: impl Into<EndpointAddr>) -> Self

Sets the remote to dial, must be provided either directly by calling this method, or through calling the api_secret builder methods.

pub async fn build(self) -> Result<Client, BuildError>

Create a new client, connected to the provide service node